# RegionalLocation


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | the name of the region or point of presence | [optional] 
**cname_domain_forwards** | [**[Domain]**](Domain.md) | The CNAME domain(s) associated with this location. | [optional] 
**org_domains** | [**[Domain]**](Domain.md) | the domain(s) available for organisations for this location. | [optional] 
**firewall_rules** | [**[RegionalFirewallRule]**](RegionalFirewallRule.md) | firewall rules required for this location | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


